@@ -27,11 +27,15 @@ class Post(models.Model):
     text = models.TextField(_('Text'))
     tags = TagField()
     hits = models.IntegerField(_('Hits'), blank=True, default=1)
-    creation_date = models.DateTimeField(_('Creation date'), auto_now_add=True)
+    creation_date = models.DateTimeField(_('Creation date'))
     user = models.ForeignKey(User, related_name="post_from")
     status =  models.BooleanField(_('Status'), default=True)
     thread_id = models.CharField(max_length=32, blank=True) # DISQUS
 
+    if "rgallery" in conf.INSTALLED_APPS:
+        from rgallery.models import Photo
+        photo = models.ManyToManyField(Photo, related_name="photo", blank=True, null=True)
+
     def set_tags(self, tags):
         Tag.objects.update_tags(self, tags)
 
